@@ -5,6 +5,7 @@
  */
 
 #include "ap_config.h"
+#include "apr_version.h"
 #include "apr_lib.h"
 #include "apr_strings.h"
 #include "httpd.h"
@@ -13,10 +14,9 @@
 #include "http_request.h"
 #include "http_log.h"
 #include "http_protocol.h"
-#include "mpm_common.h"
 #include "util_script.h"
 
-#define MOD_SCGI_VERSION "1.7"
+#define MOD_SCGI_VERSION "1.9"
 #define SCGI_PROTOCOL_VERSION "1"
 #define DEFAULT_TIMEOUT  60 /* default socket timeout */
 
@@ -24,6 +24,17 @@
 #define ENABLED 1
 #define DISABLED 2
 
+#if APR_MAJOR_VERSION == 0
+#define apr_socket_send apr_send
+#define GET_PORT(port, addr) apr_sockaddr_port_get(&(port), addr)
+#define CREATE_SOCKET(sock, family, pool) \
+	    apr_socket_create(sock, family, SOCK_STREAM, pool)
+#else
+#define GET_PORT(port, addr) ((port) = (addr)->port)
+#define CREATE_SOCKET(sock, family, pool) \
+	    apr_socket_create(sock, family, SOCK_STREAM, APR_PROTO_TCP, pool)
+#endif
+
 typedef struct {
     char *path;
     char *addr;
@@ -247,7 +258,7 @@ static apr_status_t sendall(apr_socket_t *sock, char *buf, apr_size_t len)
     apr_size_t n;
     while (len > 0) {
         n = len;
-        if ((rv = apr_send(sock, buf, &n))) return rv;
+        if ((rv = apr_socket_send(sock, buf, &n))) return rv;
         buf += n;
         len -= n;
     }
@@ -309,7 +320,7 @@ send_headers(request_rec *r, struct sockbuff *s)
     int i;
     apr_status_t rv = 0;
     apr_port_t  port = 0;
-    apr_sockaddr_port_get(&port, r->connection->remote_addr);
+    GET_PORT(port, r->connection->remote_addr);
 
     log_debug(APLOG_MARK,r, "sending headers");
     t = apr_table_make(r->pool, 40);
@@ -442,7 +453,7 @@ open_socket(apr_socket_t **sock, request_rec *r)
 
  restart:
     *sock = NULL;
-    rv = apr_socket_create(sock, sockaddr->family, SOCK_STREAM, r->pool);
+    rv = CREATE_SOCKET(sock, sockaddr->family, r->pool);
     if (rv) {
         log_err(APLOG_MARK, r, rv, "apr_socket_create() error");
         return rv;
