@@ -4,8 +4,6 @@ A pre-forking SCGI server that uses file descriptor passing to off-load
 requests to child worker processes.
 """
 
-# created 2001-11-13 NAS
-
 import sys
 import socket
 import os
@@ -40,6 +38,15 @@ def ns_reads(input):
         raise IOError, 'missing netstring terminator'
     return data
 
+def read_env(input):
+    headers = ns_reads(input)
+    items = headers.split("\0")
+    items = items[:-1]
+    assert len(items) % 2 == 0, "malformed headers"
+    env = {}
+    for i in range(0, len(items), 2):
+        env[items[i]] = items[i+1]
+    return env
 
 class SCGIHandler:
 
@@ -66,14 +73,7 @@ class SCGIHandler:
 
 
     def read_env(self, input):
-        headers = ns_reads(input)
-        items = headers.split("\0")
-        items = items[:-1]
-        assert len(items) % 2 == 0, "malformed headers"
-        env = {}
-        for i in range(0, len(items), 2):
-            env[items[i]] = items[i+1]
-        return env
+        return read_env(input)
 
     def handle_connection(self, conn):
         input = conn.makefile("r")
